==> icedtea-web_1.2.orig.tar.gz: icedtea-web-1.2/plugin/icedteanp/java/sun/applet/PluginCallRequestFactory.java <==
/* VoidPluginCallRequest -- represent Java-to-JavaScript requests
   Copyright (C) 2008  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package sun.applet;

public class PluginCallRequestFactory {

    public PluginCallRequest getPluginCallRequest(String id, String message, Long reference) {

        if (id == "member") {
            return new GetMemberPluginCallRequest(message, reference);
        } else if (id == "void") {
            return new VoidPluginCallRequest(message, reference);
        } else if (id == "window") {
            return new GetWindowPluginCallRequest(message, reference);
        } else if (id == "proxyinfo") {
            return new PluginProxyInfoRequest(message, reference);
        } else if (id == "cookieinfo") {
            return new PluginCookieInfoRequest(message, reference);
        } else {
            throw new RuntimeException("Unknown plugin call request type requested from factory");
        }
    }

}

==> icedtea-web_1.7.2.orig.tar.gz: icedtea-web-1.7.2/plugin/icedteanp/java/sun/applet/PluginCallRequestFactory.java <==
/* PluginCallRequestFactory -- contains factory methods for dispatching
 an appropriate PluginCallRequest.
   Copyright (C) 2008  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package sun.applet;

public class PluginCallRequestFactory {

    public PluginCallRequest getPluginCallRequest(String id, String message, Long reference) {

        if ("member".equals(id)) {
            return new GetMemberPluginCallRequest(message, reference);
        } else if ("void".equals(id)) {
            return new VoidPluginCallRequest(message, reference);
        } else if ("window".equals(id)) {
            return new GetWindowPluginCallRequest(message, reference);
        } else if ("proxyinfo".equals(id)) {
            return new PluginProxyInfoRequest(message, reference);
        } else if ("cookieinfo".equals(id)) {
            return new PluginCookieInfoRequest(message, reference);
        } else {
            throw new RuntimeException("Unknown plugin call request type requested from factory");
        }
    }

}
